@@ -6,7 +6,7 @@
     License as published by the Free Software Foundation; either
     version 2.1 of the License, or (at your option) version 3, or any
     later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), Nokia Corporation 
+    successor approved by the membership of KDE e.V.), Nokia Corporation
     (or its successors, if any) and the KDE Free Qt Foundation, which shall
     act as a proxy defined in Section 6 of version 3 of the license.
 
@@ -28,8 +28,6 @@
 #include "phonondefs.h"
 #include "phononnamespace.h"
 
-QT_BEGIN_HEADER
-QT_BEGIN_NAMESPACE
 
 namespace Phonon
 {
@@ -99,7 +97,7 @@ namespace Phonon
     {
         friend class FrontendInterfacePrivate;
         Q_OBJECT
-        K_DECLARE_PRIVATE(MediaObject)
+        P_DECLARE_PRIVATE(MediaObject)
         PHONON_OBJECT(MediaObject)
         /**
          * \brief Defines the time between media sources.
@@ -234,6 +232,14 @@ namespace Phonon
              */
             bool isSeekable() const;
 
+            /**
+             * \brief The time interval in milliseconds between two ticks.
+             *
+             * The %tick interval is the time that elapses between the emission
+             * of two tick signals.
+             *
+             * \returns the tick interval in milliseconds
+             */
             qint32 tickInterval() const;
 
             /**
@@ -386,6 +392,14 @@ namespace Phonon
              *
              * \return The total time in milliseconds.
              *
+             * \note The total time may change throughout playback as more accurate
+             *       calculations become available, so it is recommended to connect
+             *       and use the totalTimeChanged signal whenever possible unless
+             *       best precision is not of importance.
+             *
+             * \warning The total time is undefined until the MediaObject entered
+             *          the PlayingState. A valid total time is always indicated by
+             *          emission of the totalTimeChanged signal.
              * \see totalTimeChanged
              */
             qint64 totalTime() const;
@@ -405,6 +419,13 @@ namespace Phonon
 
         public Q_SLOTS:
 
+            /**
+             * Sets the tick interval in milliseconds.
+             *
+             * \param newTickInterval the new tick interval in milliseconds.
+             *
+             * \see tickInterval
+             */
             void setTickInterval(qint32 newTickInterval);
 
             /**
@@ -603,6 +624,12 @@ namespace Phonon
              * totalTime function can not return useful information. You have
              * to wait for this signal to know the real total time.
              *
+             * This signal may appear at any given point after a MediaSource was set.
+             * Namely in the LoadingState, BufferingState, PlayingState or PausedState.
+             *
+             * \note When changing the currentSource there is no signal emission until
+             *       a reasonable value for the new source has been calculated.
+             *
              * \param newTotalTime The length of the media file in milliseconds.
              *
              * \see totalTime
@@ -631,8 +658,6 @@ namespace Phonon
     PHONON_EXPORT MediaObject *createPlayer(Phonon::Category category, const MediaSource &source = MediaSource());
 } //namespace Phonon
 
-QT_END_NAMESPACE
-QT_END_HEADER
 
 // vim: sw=4 ts=4 tw=80
 #endif // Phonon_MEDIAOBJECT_H
