@@ -24,20 +24,18 @@
 #define VOLUMESLIDER_P_H
 
 #include <QtCore/QPointer>
-#include <QtGui/QBoxLayout>
-#include <QtGui/QIcon>
-#include <QtGui/QLabel>
-#include <QtGui/QPixmap>
-#include <QtGui/QStyle>
-#include <QtGui/QToolButton>
+#include <QBoxLayout>
+#include <QIcon>
+#include <QLabel>
+#include <QPixmap>
+#include <QStyle>
+#include <QToolButton>
 
 #include "factory_p.h"
 #include "phonondefs_p.h"
 #include "platform_p.h"
 #include "swiftslider_p.h"
 
-QT_BEGIN_NAMESPACE
-
 #ifndef QT_NO_PHONON_VOLUMESLIDER
 
 namespace Phonon
@@ -98,7 +96,5 @@ class VolumeSliderPrivate
 
 #endif //QT_NO_PHONON_VOLUMESLIDER
 
-QT_END_NAMESPACE
-
 #endif // VOLUMESLIDER_P_H
 // vim: sw=4 sts=4 et tw=100
